function h = hlagr(L,x)
% MATLAB m-file for fractional delay approximation
% by LAGRANGE INTERPOLATION method
%
% Timo Laakso   27.12.1992
% Last revision 28.12.1992
%
% Input: x = fractional delay, 0<x<=1
%        L = filter length (filter order N = L-1)
%
% Output: Filter coefficient vector h(1)..h(L)
% Subroutines: standard MATLAB functions
%
N = L-1;                         % filter order
M = N/2;                         % middle value
if (M-round(M))==0 D=x+M;        % integer part closest to middle
else D=x+M-0.5; end;
%
h=ones(1,(N+1));
%
for n=0:N
  n1=n+1;
  for k=0:N
    if (k~=n)
      h(n1) = h(n1)*(D-k)/(n-k);
    end  % if
  end; % for k
end; % for n
